import phonenumbers
import csv

from phonenumbers import geocoder, carrier, NumberParseException
from colorama import Fore, Style
from json import load, JSONDecodeError
from phoneintel.src.utils.const import *
from phoneintel.src.utils.internet import is_connected
from phoneintel.src.utils.tellows import TellowsScraper
if is_connected():
    import requests
    from urllib.parse import quote

class PhoneIntel:
    
    def __init__(self, phone_number: str, lang: str = "en") -> None:
        self.phone_number = phone_number
        self.lang = lang
        self.parsed_number = None
        self.country_code = None
        self.national_number = None
        self.coordinates_json_path = COUNTRY_COORDINATES_JSON 
        self.area = None
        self.country = None
        self.carrier_name = None
        
        self.__parse_number()
        self.__get_geolocation()
        self.__get_carrier()
        self.__print_info()
    
    def __parse_number(self) -> None:
        try:
            self.parsed_number = phonenumbers.parse(self.phone_number)
            self.country_code = self.parsed_number.country_code
            self.national_number = self.parsed_number.national_number
        except NumberParseException as e:
            print(f"{Fore.RED}[ERROR] Failed to parse phone number: {e}")
            self.parsed_number = None
    
    def __get_geolocation(self) -> None:
        if self.parsed_number:
            try:
                self.area = geocoder.description_for_number(self.parsed_number, self.lang) or f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"
                self.country = geocoder.country_name_for_number(self.parsed_number, self.lang) or f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"
            except Exception as e:
                print(f"{Fore.RED}[ERROR] Failed to get geolocation information: {e}")
                self.area = f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"
                self.country = f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"

    def __get_carrier(self) -> None:
        if self.parsed_number:
            try:
                self.carrier_name = carrier.name_for_number(self.parsed_number, self.lang) or f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"
            except Exception as e:
                print(f"{Fore.RED}[ERROR] Failed to get carrier information: {e}")
                self.carrier_name = f"{ERROR_STYLE}Unknown{Style.RESET_ALL}"
    
    def __print_info(self) -> None:
        if self.parsed_number:
            print(f"{KEY_STYLE}[-] TARGET PHONE: {VALUE_STYLE}{self.phone_number}")
            print(f"{KEY_STYLE}[-] COUNTRY: {VALUE_STYLE}{self.country}")
            print(f"{KEY_STYLE}[-] AREA/STATE: {VALUE_STYLE}{self.area}")
            print(f"{KEY_STYLE}[-] CARRIER: {VALUE_STYLE}{self.carrier_name}")
            self.__print_country_details()
            
        else:
            print(f"{Fore.RED}[ERROR] Cannot display info, parsing failed.")
    
    def __print_country_details(self) -> None:
        if self.country:
            country_details = self.__get_country_details_from_csv(self.country)
            if country_details:
                
                time_zone = country_details['Time Zone in Capital']
                if "_" in time_zone:
                    time_zone = time_zone.replace("_", " ")
                        
                print(f"{SUB_KEY_STYLE}[-] COUNTRY DETAILS:")
                print(f"{SUB_KEY_STYLE}    - Top Level Domain: {VALUE_STYLE}{country_details['Top Level Domain']}")
                print(f"{SUB_KEY_STYLE}    - Continent: {VALUE_STYLE}{country_details['Continent']}")
                print(f"{SUB_KEY_STYLE}    - Capital: {VALUE_STYLE}{country_details['Capital']}")
                print(f"{SUB_KEY_STYLE}    - Time Zone in Capital: {VALUE_STYLE}{time_zone}")
                print(f"{SUB_KEY_STYLE}    - Currency: {VALUE_STYLE}{country_details['Currency']}")
                
                
                with open(COUNTRY_LANGS_JSON, 'r', encoding='utf-8') as langs:
                    countries = load(langs)

                try:
                        for country in countries:
                            if country['cca2'] == str(country_details['Top Level Domain']).upper():
                                languages = country.get('languages', {})
                                print(f"{SUB_KEY_STYLE}    - Languages: {VALUE_STYLE}")
                                for code, name in languages.items():
                                    print(f"{VALUE_STYLE}               - {name}")
                except:
                        pass
                
                try:

                    self.__req_coordinates()

                    print(f"{SUB_KEY_STYLE}    - Latitude: {VALUE_STYLE}{self.__lat}")
                    print(f"{SUB_KEY_STYLE}    - Longitude: {VALUE_STYLE}{self.__lon}")

                except:
                    pass

                try:
                    
                    print(f"{SUB_KEY_STYLE}[-] TELLOWS DETAILS:")
                    init_tellows = TellowsScraper(f"+{self.country_code}{self.national_number}").get_info()
                    print(f"{SUB_KEY_STYLE}    - Tellows Score: {VALUE_STYLE}{init_tellows['score']}")
                    type_of_call = init_tellows["type_of_call"]
                    if type_of_call != "N/A":
                        print(f"{SUB_KEY_STYLE}    - Type of Call: {VALUE_STYLE}{init_tellows['type_of_call']}")
                    else:
                        print(f"{SUB_KEY_STYLE}    - Type of Call: {ERROR_STYLE}{'Unknown'}")
                except:

                    pass


                
                
            else:
                print(f"{Fore.RED}[ERROR] No country details found for {self.country}")
    
    def __get_country_details_from_csv(self, country_name: str) -> dict:
        try:
            with open(COUNTRY_INFO_CSV, mode='r', encoding='utf-8') as csvfile:
                reader = csv.DictReader(csvfile, delimiter=';')
                for row in reader:
                    if row['Country Name'].lower() == country_name.lower():
                        return row
        except FileNotFoundError as e:
            print(f"{Fore.RED}[ERROR] CSV file not found: {e}")
        except Exception as e:
            print(f"{Fore.RED}[ERROR] Error reading CSV file: {e}")
        return None

    def __req_coordinates(self):
        if not 'Unknown' in self.area:
            
            
            self.__api = f"https://api.bigdatacloud.net/data/reverse-geocode-client?localityLanguage=en&locality={quote(self.__state)}&countryName={quote(self.__country)}"
            self.__make_req()
        else:
            self.__load_coordinates_from_json()
            
            
    def __load_coordinates_from_json(self):
        try:
            with open(self.coordinates_json_path, 'r') as f:
                data = load(f)
                for entry in data["country_info"]:
                    if entry["country"].lower() == self.country.lower():
                        self.__lat = str(entry["latitude"])
                        self.__lon = str(entry["longitude"])
                        break
                if self.__lat is None or self.__lon is None:
                    raise ValueError(f"No coordinates found for country: {self.__country}")
        except FileNotFoundError:
            raise FileNotFoundError(f"Coordinates JSON file not found at {self.coordinates_json_path}")
        except JSONDecodeError:
            raise ValueError("Error decoding the JSON file")
    
    def __make_req(self):
        if not self.__api and (self.__lat is None or self.__lon is None):
            raise ValueError("API URL is not set and coordinates are not found in the JSON. Call req_coordinates() first.")

        if self.__api:
            try:
                response = requests.get(self.__api, timeout=5)
                response.raise_for_status()
            except requests.exceptions.HTTPError as e:
                separator()
                print(f"[!] Error in map request {e}")
            except requests.exceptions.RequestException as e:
                separator()
                print(f"[!] Error in map request {e}")

            if response.status_code == 200:
                response_data = response.json()
                if 'latitude' in response_data and 'longitude' in response_data:
                    self.__lon = response_data['longitude']
                    self.__lat = response_data['latitude']
                else:
                    raise ValueError("No coordinates found for the provided location.")
            else:
                separator()
                print(f"[!] Error in map request")



#!/usr/bin/env python3
from phoneintel.src.utils import *
from time import sleep
from colorama import init, Fore, Style
import argparse
import sys
import subprocess

def open_map_info()->None:
        print(Fore.CYAN+"[!] Opening Map...\n")
        

# Constants
DORKS_TYPES = [
    "social_networks", "forums", "classifieds", "ecommerce",
    "news", "blogs", "job_sites", "pastes", "reputation", "phone_directories", "people_search",  "all"
]
init(autoreset=True)

def run_phoneintel(phone, map_true: bool = False):
    try:
        banner()
        separator()
        init = PhoneIntel(phone)

        if map_true:
            separator()
            open_map_info()
            PhoneIntelMap(init.country, init.area)
        separator()
    except Exception as e:
        print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")

def run_phoneinteltext_path(input_path, map_true: bool = False):
    try:
        banner()
        numbers = PhoneIntelText(input_path).get_phone_numbers()
        for number in numbers:
            try:
                separator()
                init = PhoneIntel(number)  

                if map_true and "Unknown" not in init.area:
                    separator()
                    open_map_info()
                    PhoneIntelMap(init.country, init.area)
                    sleep(0.5)
            except Exception as e:
                print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")
        separator()
    except Exception as e:
        print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")

def run_phoneinteltext_string(string, map_true: bool = False):
    try:
        banner()
        numbers = PhoneIntelText(string, False).get_phone_numbers()

        for number in numbers:
            try:
                separator()
                init = PhoneIntel(number) 

                if map_true and "Unknown" not in init.area:
                    separator()
                    open_map_info()
                    PhoneIntelMap(init.country, init.area)
                    sleep(0.3)
            except Exception as e:
                print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")
        separator()
    except Exception as e:
        print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")

def run_phoneinteldorking(phone, type, map_true: bool = False):
    try:
        banner()
        separator()
        init = PhoneIntel(phone)

        phone_ = init.phone_number
        dorks_banner()
        print("\n")
        dorks = PhoneIntelDorking(phone_, type)

        if map_true and "Unknown" not in init.area:
            separator()
            open_map_info()
            PhoneIntelMap(init.country, init.area)

        separator()
    except Exception as e:
        print(f"{Fore.RED}Error: {str(e)}{Style.RESET_ALL}")

def install_dependencies():

    dependencies = {
        "colorama": "0.4.6",
        "phonenumbers": "8.13.42",
        "requests": "2.32.3",
        "beautifulsoup4": "4.12.3"
    }


    print("Required Dependencies:")
    for k, v in dependencies.items():
        print(k)
        
    user_input = input("Do you want to install the required dependencies? (yes/no): ").strip().lower()

    if user_input not in ['yes', 'y']:
        print("Installation of dependencies aborted by user.")
        return False

    # Comando base de pip
    pip_command = [sys.executable, "-m", "pip", "install", "--upgrade", "pip"]
    
    print(f"Updating pip...")
    try:
        subprocess.check_call(pip_command)
    except subprocess.CalledProcessError as e:
        print(f"Error updating pip: {e}")
        sys.exit(1)


    pip_command = [sys.executable, "-m", "pip", "install"]
    
    print(f"Installing pip packages...")
    for package, version in dependencies.items():
        try:

            __import__(package)
            print(f"{package} is already installed.")
        except ImportError:

            install_command = pip_command + [f"{package}=={version}"]
            try:
                print(f"Installing {package}...")
                subprocess.check_call(install_command)
                print(f"{package} installed successfully.")
            except subprocess.CalledProcessError as e:
                print(f"Error installing {package}: {e}")
                sys.exit(1)

    print("All dependencies have been installed successfully.")
    return True



class CustomHelp:
    """Custom help formatter to create a more detailed and aesthetic help menu."""
    def __init__(self) -> None:
        print(self.format_help())
    def format_help(self):
        # Header
        help_text = "\nPhoneIntel: OSINT Tool\n"
        help_text += "=======================\n\n"
        help_text += "Description:\n"
        help_text += "  This tool processes phone numbers to perform various actions including fetching information, searching, and generating dorks.\n\n"

        # Usage
        help_text += "Usage:\n\n"
        help_text += "  phoneintel <command> [options]\n\n"

        # Commands
        help_text += "Commands:\n\n"
        help_text += "  info    Execute info command\n"
        help_text += "  search  Execute search command\n"
        help_text += "  dorks   Execute dorks command\n\n"

        # Detailed Command Help
        help_text += "Detailed Command Help:\n\n"
        help_text += "  info:\n\n"
        help_text += "    phoneintel info <phone> [--map]\n\n"
        help_text += "    Arguments:\n\n"
        help_text += "      <phone>  Phone number to be processed\n"
        help_text += "      --map    Execute map function (optional)\n\n"

        help_text += "  search:\n\n"
        help_text += "    phoneintel search [<phone>] [--input FILE | --string TEXT] [--map]\n\n"
        help_text += "    Arguments:\n\n"
        help_text += "      <phone>   Phone number to be processed (optional)\n"
        help_text += "      --input   Input file for search (optional)\n"
        help_text += "      --string  Search string (optional)\n"
        help_text += "      --map     Execute map function (optional)\n\n"

        help_text += "  dorks:\n\n"
        help_text += "    phoneintel dorks <phone> --type TYPE [--map]\n\n"
        help_text += "    Arguments:\n"
        help_text += "      <phone>  Phone number to be processed\n"
        help_text += "      --type   Type of dorks (required)\n"
        help_text += "               Valid types: {}\n".format(", ".join(DORKS_TYPES))
        help_text += "      --map    Execute map function (optional)\n\n"

        return help_text



def main():
    
    try:
        __import__("requests")
        __import__("phonenumbers")
        __import__("bs4")
        __import__("colorama")

    except Exception as e:
        print(f"[Error] {e}")
        if install_dependencies():
            
            main()

    
    parser = argparse.ArgumentParser(
        description="PhoneIntel Argument Processor",
        add_help=False
    )

    group = parser.add_mutually_exclusive_group(required=True)
    group.add_argument('--info', action='store_true', help='Execute info command')
    group.add_argument('--search', action='store_true', help='Execute search')
    group.add_argument('--dorks', action='store_true', help='Execute dorks command')
    group.add_argument('-h', '--help', action='store_true', help='Show help message and exit')

    parser.add_argument('phone', nargs='?', type=str, help='Phone number to be processed')

    search_group = parser.add_argument_group('search_group', 'Arguments for search')
    search_group.add_argument('--input', type=str, help='Input file for search')
    search_group.add_argument('--string', type=str, help='Search string')

    dorks_group = parser.add_argument_group('dorks_group', 'Arguments for dorks')
    dorks_group.add_argument('--type', type=str, help='Type of dorks')

    parser.add_argument('--map', action='store_true', help='Execute map function')

    args = parser.parse_args()
    
    
    if args.help:
        CustomHelp()
        return

    if args.search and not (args.input or args.string or args.phone):
        parser.error('--search requires --input, --string, or phone number')
    if args.dorks and not args.type:
        parser.error('--dorks requires --type')
    if args.dorks and args.type.strip().lower() not in DORKS_TYPES:
        parser.error(f'Invalid dork type: {args.type}. Valid types are: {", ".join(DORKS_TYPES)}')

    phone_number = args.phone
    
    if not args.search:
        phone_number = str(phone_number).strip()
        if not phone_number.startswith("+"):
            separator()
            print(Fore.YELLOW+Style.BRIGHT+"[!] Not an associated country number, adding +1")
            phone_number = f"+1{phone_number}"
        
    
    
    if args.info:
        if phone_number is None:
            parser.error('--info requires a phone')
        else:
            if args.map:
                run_phoneintel(phone_number, args.map)
            else:
                run_phoneintel(phone_number)
    elif args.search:
        if phone_number is None and not (args.input or args.string):
            parser.error('--search requires --phone or (--input or --string)')
        if args.input:
            if args.map:
                run_phoneinteltext_path(args.input, args.map)
            else:
                run_phoneinteltext_path(args.input)
        elif args.string:
            if args.map:
                run_phoneinteltext_string(args.string, args.map)
            else:
                run_phoneinteltext_string(args.string)
    elif args.dorks:
        if phone_number is None:
            parser.error('--dorks requires --phone')
        else:
            if args.map:
                run_phoneinteldorking(phone_number, args.type, args.map)
            else:
                
                run_phoneinteldorking(phone_number, args.type)
    
    
    
    
    
    
if __name__ == "__main__":
    main()



from .dorking import PhoneIntelDorking
from .phone import PhoneIntel
from .text import PhoneIntelText
from .map import PhoneIntelMap
from .const import *
from .internet import is_connected
from .tellows import TellowsScraper




from colorama import Fore, Style
from os import path
from time import sleep

BANNER = f'''{Fore.BLUE}
-------------------------------------------

        ╔═╗╦ ╦╔═╗╔╗╔╔═╗╦╔╗╔╔╦╗╔═╗╦  
        ╠═╝╠═╣║ ║║║║║╣ ║║║║ ║ ║╣ ║  
        ╩  ╩ ╩╚═╝╝╚╝╚═╝╩╝╚╝ ╩ ╚═╝╩═╝
        
-------------------------------------------'''
BANNER_2 = f'''{Fore.BLUE}
-------------------------------------------
            ╔╦╗╔═╗╦═╗╦╔═╔═╗
             ║║║ ║╠╦╝╠╩╗╚═╗
            ═╩╝╚═╝╩╚═╩ ╩╚═╝
-------------------------------------------'''
SUB_KEY_STYLE = Fore.YELLOW + Style.BRIGHT
KEY_STYLE = Fore.YELLOW + Style.BRIGHT
VALUE_STYLE = Fore.GREEN + Style.NORMAL
ERROR_STYLE = Fore.RED + Style.BRIGHT
MAIN_PATH = path.normpath(__file__+"/../..")
COUNTRY_INFO_CSV = path.join(MAIN_PATH, "resources", "countries", "countries.csv")
USER_AGENTS = path.join(MAIN_PATH, "resources", "user_agents", "agents.txt")
DORKS_JSON = path.join(MAIN_PATH, "resources", "dorks", "dorks.json")
COUNTRY_COORDINATES_JSON = path.join(MAIN_PATH, "resources", "countries", "country_coordinates.json")
COUNTRY_LANGS_JSON = path.join(MAIN_PATH, "resources", "countries", "countries_langs.json")
def separator()->None:
    
    print(Fore.BLUE+"-------------------------------------------")
    
def banner()->None:
        print(BANNER)
        sleep(0.3)
        print(Fore.RESET+"[!] VERSION 1.0\n")
        sleep(0.3)
        print("[!] GITHUB https://github.com/phoneintel/phoneintel\n")
        sleep(0.3)
        print("[!] LICENSED UNDER Apache-2.0 license")
        sleep(0.5)
        
def dorks_banner()->None:
        print(BANNER_2)
        sleep(0.3)


def invalid_path()->None:
        print(Fore.RED+"[!] Invalid Path...\n")


import requests
import webbrowser
import json
from urllib.parse import quote
from phoneintel.src.utils.const import separator, COUNTRY_COORDINATES_JSON

class PhoneIntelMap:
    
    def __init__(self, country: str, state: str = None) -> None:
        self.__country = country
        self.__state = state
        self.__api = None
        self.__lon = None
        self.__lat = None
        self.coordinates_json_path = COUNTRY_COORDINATES_JSON 
        self.__req_coordinates()
        try:
            self.__make_req()
            if self.__lon:
                self.open_map()
        except Exception as e:
            print(f"An error occurred: {e}")
        
    def __req_coordinates(self):
        if not 'Unknown' in self.__state:
            
            self.__api = f"https://api.bigdatacloud.net/data/reverse-geocode-client?localityLanguage=en&locality={quote(self.__state)}&countryName={quote(self.__country)}"
        else:
            self.__load_coordinates_from_json()
            
            
    def __load_coordinates_from_json(self):
        try:
            with open(self.coordinates_json_path, 'r') as f:
                data = json.load(f)
                for entry in data["country_info"]:
                    if entry["country"].lower() == self.__country.lower():
                        self.__lat = str(entry["latitude"])
                        self.__lon = str(entry["longitude"])
                        break
                if self.__lat is None or self.__lon is None:
                    raise ValueError(f"No coordinates found for country: {self.__country}")
        except FileNotFoundError:
            raise FileNotFoundError(f"Coordinates JSON file not found at {self.coordinates_json_path}")
        except json.JSONDecodeError:
            raise ValueError("Error decoding the JSON file")
    
    def __make_req(self):
        if not self.__api and (self.__lat is None or self.__lon is None):
            raise ValueError("API URL is not set and coordinates are not found in the JSON. Call req_coordinates() first.")

        if self.__api:
            try:
                response = requests.get(self.__api, timeout=5)
                response.raise_for_status()
            except requests.exceptions.HTTPError as e:
                separator()
                print(f"[!] Error in map request {e}")
            except requests.exceptions.RequestException as e:
                separator()
                print(f"[!] Error in map request {e}")

            if response.status_code == 200:
                response_data = response.json()
                if 'latitude' in response_data and 'longitude' in response_data:
                    self.__lon = response_data['longitude']
                    self.__lat = response_data['latitude']
                else:
                    raise ValueError("No coordinates found for the provided location.")
            else:
                separator()
                print(f"[!] Error in map request")
            
    def open_map(self):
        
        if self.__lon and self.__lat:
            map_url = f"https://www.openstreetmap.org/?mlat={self.__lat}&mlon={self.__lon}#map=12/{self.__lat}/{self.__lon}"
            webbrowser.open(map_url)
        else:
            raise ValueError("Coordinates are not set. Ensure the API request was successful.")




import requests
from bs4 import BeautifulSoup
import urllib.parse
from colorama import Fore, Style
from phoneintel.src.utils.const import *

class TellowsScraper:
    def __init__(self, phone_number):
        self.phone_number = phone_number
        self.base_url = 'https://www.tellows.com/num/'
        self.soup = None
        self.score = None
        self.type_of_call = None

    def fetch_data(self):
        url = self.base_url + urllib.parse.quote(self.phone_number)
        print(f"{SUB_KEY_STYLE}    - Tellows URL: {VALUE_STYLE}{url}")
        
        response = requests.get(url, timeout=5)
        response.raise_for_status()
        self.soup = BeautifulSoup(response.text, 'html.parser')

    def extract_score(self):
        try:
            score_image = self.soup.find('div', {'id': 'tellowsscore'}).find('img')
            self.score = score_image['alt'].split(': Score ')[1].strip() if score_image else 'N/A'
        except:
            self.score = 'N/A'

    def extract_type_of_call(self):
        try:
            self.type_of_call = self.soup.find('b', text='Types of call:').find_next_sibling(text=True).strip()
        except:
            self.type_of_call = 'N/A'

    def get_info(self):
        try:
            self.fetch_data()
            self.extract_score()
            self.extract_type_of_call()
            return {
                'phone_number': self.phone_number,
                'score': self.score,
                'type_of_call': self.type_of_call
            }
        except:
            return {
                'phone_number': self.phone_number,
                'score': "Unknow",
                'type_of_call': "Unknow"
            }

    def set_phone_number(self, new_number):
        self.phone_number = new_number




import os
import re
import phonenumbers
from phoneintel.src.utils.const import invalid_path, separator
class PhoneIntelText:
    
    def __init__(self, text_or_path: str, path: bool = True) -> None:
        if not isinstance(text_or_path, str):
            raise ValueError("Invalid input, must be a string")
        
        self.__target = text_or_path
        self.__phone_numbers = []
        if path:
            if os.path.exists(path):
                self.__path = os.path.realpath(self.__target)
                if os.path.isdir(self.__path):
                    self.__process_directory(self.__path)
                elif os.path.isfile(self.__path):
                    self.__process_file(self.__path)
            else:
                invalid_path()
                return
                
        else:
            self.__process_text(self.__target)

    def __process_directory(self, directory_path: str) -> None:
        for root, _, files in os.walk(directory_path):
            for file in files:
                if file.lower().endswith('.txt'):
                    file_path = os.path.join(root, file)
                    self.__process_file(file_path)

    def __process_file(self, file_path: str) -> None:
        try:
            with open(file_path, 'r', encoding='utf-8') as file:
                content = file.read()
                if content:
                    self.__extract_phone_numbers(content)
        except Exception as e:
            print(f"Error reading file {file_path}: {e}")

    def __process_text(self, text: str) -> None:
        if text:
            self.__extract_phone_numbers(text)

    def __extract_phone_numbers(self, content: str) -> None:
        lines = content.splitlines()

        phone_pattern = re.compile(r'\+?\d[\d\s\-()]{7,}\d')

        for line in lines:
            potential_numbers = phone_pattern.findall(line)
 
            for number in potential_numbers:
                try:

                    cleaned_number = re.sub(r'[^\d\+]', '', number)
                    parsed_number = phonenumbers.parse(cleaned_number, None)
                    number = f"+{parsed_number.country_code}{parsed_number.national_number}"
                    self.__phone_numbers.append(number)
                except phonenumbers.NumberParseException:
                    continue

    def get_phone_numbers(self) -> list:
        return self.__phone_numbers




from setuptools import setup, find_packages

setup(
    name='phoneintel',
    version='1.0.6',
    description='A tool for processing phone numbers with OSINT capabilities.',
    author='PhoneIntel',
    author_email='phoneintel@proton.me',
    license='Apache License 2.0',
    url='https://github.com/phoneintel/phoneintel',
    packages=find_packages(include=['phoneintel', 'phoneintel.src', 'phoneintel.src.utils']),
    include_package_data=True,
    project_urls={
    'Bug Tracker': 'https://github.com/phoneintel/phoneintel/issues',
    'Documentation': 'https://phoneintel.github.io/',
    'Source Code': 'https://github.com/phoneintel/phoneintel',
    },
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=[
        'colorama==0.4.6',
        'phonenumbers==8.13.42',
        'requests==2.32.3',
        'beautifulsoup4==4.12.3',
    ],
    entry_points={
        'console_scripts': [
            'phoneintel=phoneintel.main:main',
        ],
    },
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Science/Research',
    'License :: OSI Approved :: Apache Software License',
    'Programming Language :: Python :: 3.11',
    ],
)



import urllib.parse
from phonenumbers import parse, geocoder
from colorama import Fore, init
from json import load, JSONDecodeError
from phoneintel.src.utils.const import DORKS_JSON

init(autoreset=True)

class PhoneIntelDorking:
    
    def __init__(self, target: str, dork_type: str = "social_networks") -> None:
        self.__target = target
        self.__type = dork_type.lower().strip()
        phonenumbers_init = parse(self.__target)
        self.__country_code = phonenumbers_init.country_code
        self.__national_number = phonenumbers_init.national_number
        self.__country = geocoder.country_name_for_number(phonenumbers_init, "en")
        self.__dorks_base = self.__json_to_dict(DORKS_JSON)
        self.__dorks_ready = []
        self.__process_dorks()
        self.__print_dorks()
        
    def __process_dorks(self) -> None:
        dork_categories = ["social_networks", "forums", "classifieds", "ecommerce", "news", "blogs", "job_sites", "pastes", "reputation", "phone_directories", "people_search"]

        if self.__type in dork_categories:
            self.__replace_placeholders(self.__dorks_base[self.__type])
        elif self.__type == "all":
            for category in dork_categories:
                self.__replace_placeholders(self.__dorks_base[category])
                
    def __replace_placeholders(self, dork_list: list) -> None:
        for dork in dork_list:
            dork = dork.replace('{phone}', str(self.__target))
            dork = dork.replace('{national_phone}', str(self.__national_number))
            dork = dork.replace('{country}', str(self.__country))
            dork = dork.replace('{country_code}', str(self.__country_code))
            self.__dorks_ready.append(dork)
    
    def __json_to_dict(self, json_path: str) -> dict:
        try:
            with open(json_path, 'r', encoding='utf-8') as file:
                return load(file)
        except FileNotFoundError:
            print(f"Error: El archivo {json_path} no se encontró.")
        except JSONDecodeError:
            print(f"Error: El archivo {json_path} no es un JSON válido.")
        return {}

    def __print_dorks(self) -> None:
        base_url = "https://www.google.com/search?q="
        type = self.__type
        if "_" in type:
            type = type.replace("_", " ")
        type = type.capitalize()
        for counter, dork in enumerate(self.__dorks_ready, start=1):
            encoded_dork = urllib.parse.quote(dork)
            full_url = f"{base_url}{encoded_dork}"
            print(Fore.YELLOW + f"{type} Dork {counter}: " + Fore.CYAN + full_url)
            print("\n")
